ESG
---

.. autosummary::
    :toctree: api/
    :template: ../../../../_templates/class_template.rst

    prismstudio.esg.dataitems
    prismstudio.esg.environmental
    prismstudio.esg.social
    prismstudio.esg.governance
    prismstudio.esg.diversity
    prismstudio.esg.overall

